@@ -356,7 +356,6 @@ static gboolean elektra_settings_backend_get_writable (GSettingsBackend * backen
 	ElektraSettingsBackend * esb = (ElektraSettingsBackend *) backend;
 	gchar * pathToWrite = g_strconcat (G_ELEKTRA_SETTINGS_USER, G_ELEKTRA_SETTINGS_PATH, name, NULL);
 	GElektraKey * gkey = gelektra_keyset_lookup_byname (esb->gks, pathToWrite, GELEKTRA_KDB_O_NONE);
-	// TODO answer why inside the if block
 	if (gkey == NULL) gkey = gelektra_key_new (pathToWrite, KEY_VALUE, G_ELEKTRA_TEST_STRING, KEY_END);
 	g_free (pathToWrite);
 	if (gkey == NULL) return FALSE;
@@ -373,21 +372,22 @@ static void elektra_settings_key_changed (GDBusConnection * connection G_GNUC_UN
 	gchar const * keypathname = g_variant_get_string (variant, NULL);
 	ElektraSettingsBackend * esb = (ElektraSettingsBackend *) user_data;
 	GElektraKeySet * ks = gelektra_keyset_dup (esb->subscription_gks);
-	gelektra_keyset_rewind (ks);
 	GElektraKey * key = gelektra_key_new (keypathname, KEY_VALUE, "", KEY_END);
 	g_log (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG, "%s %s!",
 	       "GSEttings Path: ", (g_strstr_len (g_strstr_len (keypathname, -1, "/") + 1, -1, "/")));
-	gelektra_keyset_next (ks);
-	do
+	GElektraKey * item;
+	gssize pos = 0;
+	while ((item = gelektra_keyset_at (ks, pos)) != NULL)
 	{
-		if (gelektra_key_isbeloworsame (key, gelektra_keyset_current (ks)))
+		if (gelektra_key_isbeloworsame (key, item))
 		{
 			g_log (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG, "%s!", "Subscribed key changed");
 			gchar * gsettingskeyname = g_strdup (g_strstr_len (g_strstr_len (keypathname, -1, "/") + 1, -1, "/"));
 			g_settings_backend_changed (user_data, gsettingskeyname, NULL);
 			g_free (gsettingskeyname);
 		}
-	} while (gelektra_keyset_next (ks) != NULL);
+		pos++;
+	}
 	g_variant_unref (variant);
 }
 
