@@ -8,23 +8,13 @@ import com.sun.jna.Pointer;
 /**
  * A keyset holds together a set of keys.
  */
-public class KeySet implements java.lang.Iterable<Key> {
+public class KeySet implements Iterable<Key>
+{
 
 	// constants
 	public static final int KDB_O_NONE = 0;
 	public static final int KDB_O_DEL = 1;
 	public static final int KDB_O_POP = 1 << 1;
-	public static final int KDB_O_NODIR = 1 << 2;
-	public static final int KDB_O_DIRONLY = 1 << 3;
-	public static final int KDB_O_NOREMOVE = 1 << 6;
-	public static final int KDB_O_REMOVEONLY = 1 << 7;
-	public static final int KDB_O_INACTIVE = 1 << 8;
-	public static final int KDB_O_SYNC = 1 << 9;
-	public static final int KDB_O_SORT = 1 << 10;
-	public static final int KDB_O_NORECURSIVE = 1 << 11;
-	public static final int KDB_O_NOCASE = 1 << 12;
-	public static final int KDB_O_WITHOWNER = 1 << 13;
-	public static final int KDB_O_NOALL = 1 << 14;
 	public static final Pointer KS_END = null;
 
 	private Pointer ks;
@@ -34,16 +24,23 @@ public class KeySet implements java.lang.Iterable<Key> {
 	 *
 	 * @param p Pointer to another KeySet in long format
 	 */
-	protected KeySet(final long p) {
-		ks = new Pointer(p);
+	protected KeySet (final long p)
+	{
+		ks = new Pointer (p);
 	}
 
 	/**
 	 * Helper constructor for duplication by pointer
+	 * The pointer may not be null or an IllegalArgumentException is thrown
 	 *
 	 * @param p Pointer to another KeySet
 	 */
-	protected KeySet(final Pointer p) {
+	public KeySet (final Pointer p)
+	{
+		if (p == null)
+		{
+			throw new IllegalArgumentException ("Passed pointer should not be null");
+		}
 		ks = p;
 	}
 
@@ -58,20 +55,24 @@ public class KeySet implements java.lang.Iterable<Key> {
 	 * @return New key set with the given initial data
 	 * @see #create()
 	 */
-	protected static KeySet create(final int alloc, final Object... args) {
+	protected static KeySet create (final int alloc, final Object... args)
+	{
 		int i = 0;
-		for (i = 0; i < args.length; ++i) {
-			if (args[i] instanceof Key) {
+		for (i = 0; i < args.length; ++i)
+		{
+			if (args[i] instanceof Key)
+			{
 				final Key k = (Key) args[i];
-				args[i] = k.get();
+				args[i] = k.get ();
 			}
 		}
-		if (args.length > 0 && args[i - 1] != KeySet.KS_END) {
-			final Object[] sanitized = Arrays.copyOf(args, args.length + 1);
+		if (args.length > 0 && args[i - 1] != KeySet.KS_END)
+		{
+			final Object[] sanitized = Arrays.copyOf (args, args.length + 1);
 			sanitized[i] = KeySet.KS_END;
-			return new KeySet(Elektra.INSTANCE.ksNew(alloc < sanitized.length ? alloc + 1 : sanitized.length, sanitized));
+			return new KeySet (Elektra.INSTANCE.ksNew (alloc < sanitized.length ? alloc + 1 : sanitized.length, sanitized));
 		}
-		return new KeySet(Elektra.INSTANCE.ksNew(alloc, args));
+		return new KeySet (Elektra.INSTANCE.ksNew (alloc, args));
 	}
 
 	/**
@@ -79,8 +80,9 @@ public class KeySet implements java.lang.Iterable<Key> {
 	 *
 	 * @return New key set
 	 */
-	public static KeySet create() {
-		return create(16);
+	public static KeySet create ()
+	{
+		return create (16);
 	}
 
 	/**
@@ -91,21 +93,23 @@ public class KeySet implements java.lang.Iterable<Key> {
 	 * @return New key set with the given initial data
 	 * @see #create()
 	 */
-	public static KeySet create(final int alloc, final Key... args) {
-		if (args == null)
-			return create(alloc);
-		final Object[] keys = Arrays.copyOf(args, args.length + 1, Object[].class);
+	public static KeySet create (final int alloc, final Key... args)
+	{
+		if (args == null) return create (alloc);
+		final Object[] keys = Arrays.copyOf (args, args.length + 1, Object[].class);
 		keys[args.length] = KS_END;
-		return create(alloc, keys);
+		return create (alloc, keys);
 	}
 
 	/**
 	 * Clean-up method to release keyset reference
 	 */
-	public void release() {
+	public void release ()
+	{
 		// Otherwise this reference would most likely be lost, resulting in a potential leak
-		if (ks != null) {
-			Elektra.INSTANCE.ksDel(ks);
+		if (ks != null)
+		{
+			Elektra.INSTANCE.ksDel (ks);
 		}
 		ks = null;
 	}
@@ -113,9 +117,9 @@ public class KeySet implements java.lang.Iterable<Key> {
 	/**
 	 * Clean-up method to inform underlying c-library about the release of the keyset reference
 	 */
-	@Override
-	protected void finalize() throws Throwable {
-		release();
+	@Override protected void finalize () throws Throwable
+	{
+		release ();
 	}
 
 	/**
@@ -123,28 +127,30 @@ public class KeySet implements java.lang.Iterable<Key> {
 	 *
 	 * @return Custom KeySetIterator
 	 */
-	@Override
-	public java.util.Iterator<Key> iterator() {
-		return new KeySetIterator(this);
+	@Override public Iterator<Key> iterator ()
+	{
+		return new KeySetIterator (this);
 	}
 
 	/**
 	 * Basic java function that represents object as String.<br>
-	 * Iterates though all keys in this key set and appends their representation to the output. Uses the toString() function of the Key
+	 * Iterates though all keys in this key set and appends their representation to the output. Uses the toString()
+	 * function of the Key
 	 * objects.
 	 *
 	 * @return List of key-value pairs contained in this key set
 	 */
-	@Override
-	public String toString() {
-		final StringBuilder sb = new StringBuilder();
+	@Override public String toString ()
+	{
+		final StringBuilder sb = new StringBuilder ();
 		String sep = "";
-		for (final Key k : this) {
-			sb.append(sep);
-			sb.append(k);
+		for (final Key k : this)
+		{
+			sb.append (sep);
+			sb.append (k);
 			sep = "\n";
 		}
-		return sb.toString();
+		return sb.toString ();
 	}
 
 	/*
@@ -156,29 +162,32 @@ public class KeySet implements java.lang.Iterable<Key> {
 	 *
 	 * @return New KeySet containing the same key references as this object does
 	 */
-	public KeySet dup() {
-		return new KeySet(Elektra.INSTANCE.ksDup(get()));
+	public KeySet dup ()
+	{
+		return new KeySet (Elektra.INSTANCE.ksDup (get ()));
 	}
 
 	/**
 	 * Copies key references from other key set
 	 *
 	 * @param other Key set that is used as source
-	 * @return 1 in case of success, 0 if source was NULL and dest (this) was cleared successfully, -1 in case of an error (null pointer)
+	 * @retval 1 in case of success, 0 if source was NULL and dest (this) was cleared successfully, -1 in case of an
+	 * error (null pointer)
 	 */
-	public int copy(final KeySet other) {
-		if (other == null)
-			return -1;
-		return Elektra.INSTANCE.ksCopy(get(), other.get());
+	public int copy (final KeySet other)
+	{
+		if (other == null) return -1;
+		return Elektra.INSTANCE.ksCopy (get (), other.get ());
 	}
 
 	/**
 	 * Helper function to check if synchronization is necessary
 	 *
-	 * @return 1 if sync is necessary, 0 if no sync is necessary, -1 in case of an error (null key)
+	 * @retval 1 if sync is necessary, 0 if no sync is necessary, -1 in case of an error (null key)
 	 */
-	public int needsSync() {
-		return Elektra.INSTANCE.ksNeedSync(get());
+	public int needsSync ()
+	{
+		return Elektra.INSTANCE.ksNeedSync (get ());
 	}
 
 	/**
@@ -186,8 +195,9 @@ public class KeySet implements java.lang.Iterable<Key> {
 	 *
 	 * @return Size of key set (number of possible keys)
 	 */
-	public int length() {
-		return Elektra.INSTANCE.ksGetSize(get());
+	public int length ()
+	{
+		return Elektra.INSTANCE.ksGetSize (get ());
 	}
 
 	/**
@@ -196,11 +206,13 @@ public class KeySet implements java.lang.Iterable<Key> {
 	 * @param k Key to append
 	 * @return Index of key in key set; starting from 1, -1 if null was provided
 	 */
-	public int append(final Key k) {
-		if (k == null) {
+	public int append (final Key k)
+	{
+		if (k == null)
+		{
 			return -1;
 		}
-		return Elektra.INSTANCE.ksAppendKey(get(), k.get());
+		return Elektra.INSTANCE.ksAppendKey (get (), k.get ());
 	}
 
 	/**
@@ -209,15 +221,18 @@ public class KeySet implements java.lang.Iterable<Key> {
 	 * @param ks Key set to append
 	 * @return Highest new index of key in key set; starting from 1, -1 if null was provided
 	 */
-	public int append(final KeySet ks) {
-		if (ks == null) {
+	public int append (final KeySet ks)
+	{
+		if (ks == null)
+		{
 			return -1;
 		}
 
 		int result = -1;
-		final Iterator<Key> iter = ks.iterator();
-		while (iter.hasNext()) {
-			result = Elektra.INSTANCE.ksAppendKey(get(), iter.next().get());
+		final Iterator<Key> iter = ks.iterator ();
+		while (iter.hasNext ())
+		{
+			result = Elektra.INSTANCE.ksAppendKey (get (), iter.next ().get ());
 		}
 		return result;
 	}
@@ -228,10 +243,10 @@ public class KeySet implements java.lang.Iterable<Key> {
 	 * @param cutpoint Key that is used as cutting point
 	 * @return New KeySet containing all keys until the cutting point, this if null was provided
 	 */
-	public KeySet cut(final Key cutpoint) {
-		if (cutpoint == null)
-			return this;
-		return new KeySet(Elektra.INSTANCE.ksCut(get(), cutpoint.get()));
+	public KeySet cut (final Key cutpoint)
+	{
+		if (cutpoint == null) return this;
+		return new KeySet (Elektra.INSTANCE.ksCut (get (), cutpoint.get ()));
 	}
 
 	/**
@@ -239,8 +254,9 @@ public class KeySet implements java.lang.Iterable<Key> {
 	 *
 	 * @return First Key in the set
 	 */
-	public Key pop() {
-		return new Key(Elektra.INSTANCE.ksPop(get()));
+	public Key pop ()
+	{
+		return new Key (Elektra.INSTANCE.ksPop (get ()));
 	}
 
 	/**
@@ -248,8 +264,9 @@ public class KeySet implements java.lang.Iterable<Key> {
 	 *
 	 * @return Current Key in iteration
 	 */
-	public Key current() {
-		return new Key(Elektra.INSTANCE.ksCurrent(get()));
+	public Key current ()
+	{
+		return new Key (Elektra.INSTANCE.ksCurrent (get ()));
 	}
 
 	/**
@@ -257,17 +274,19 @@ public class KeySet implements java.lang.Iterable<Key> {
 	 *
 	 * @return Next Key in key set
 	 */
-	public Key next() {
-		return new Key(Elektra.INSTANCE.ksNext(get()));
+	public Key next ()
+	{
+		return new Key (Elektra.INSTANCE.ksNext (get ()));
 	}
 
 	/**
 	 * Helper function that rewinds the current key set
 	 *
-	 * @return
+	 * @retval 0 on success, -1 on NullPointer
 	 */
-	public int rewind() {
-		return Elektra.INSTANCE.ksRewind(get());
+	public int rewind ()
+	{
+		return Elektra.INSTANCE.ksRewind (get ());
 	}
 
 	/**
@@ -275,8 +294,9 @@ public class KeySet implements java.lang.Iterable<Key> {
 	 *
 	 * @return First element of the key set
 	 */
-	public Key head() {
-		return new Key(Elektra.INSTANCE.ksHead(get()));
+	public Key head ()
+	{
+		return new Key (Elektra.INSTANCE.ksHead (get ()));
 	}
 
 	/**
@@ -284,8 +304,9 @@ public class KeySet implements java.lang.Iterable<Key> {
 	 *
 	 * @return Last element of the key set
 	 */
-	public Key tail() {
-		return new Key(Elektra.INSTANCE.ksTail(get()));
+	public Key tail ()
+	{
+		return new Key (Elektra.INSTANCE.ksTail (get ()));
 	}
 
 	/**
@@ -293,18 +314,20 @@ public class KeySet implements java.lang.Iterable<Key> {
 	 *
 	 * @return Cursor position as integer; initially -1, incremented by next()
 	 */
-	public int getCursor() {
-		return Elektra.INSTANCE.ksGetCursor(get());
+	public int getCursor ()
+	{
+		return Elektra.INSTANCE.ksGetCursor (get ());
 	}
 
 	/**
 	 * Helper function that sets the current cursor of the key set
 	 *
 	 * @param cursor Cursor position as integer
-	 * @return 1 in case of success
+	 * @retval 1 in case of success
 	 */
-	public int setCursor(final int cursor) {
-		return Elektra.INSTANCE.ksSetCursor(get(), cursor);
+	public int setCursor (final int cursor)
+	{
+		return Elektra.INSTANCE.ksSetCursor (get (), cursor);
 	}
 
 	/**
@@ -313,8 +336,9 @@ public class KeySet implements java.lang.Iterable<Key> {
 	 * @param cursor Cursor position used to fetch key; starting from 0
 	 * @return Key at given cursor position
 	 */
-	public Key at(final int cursor) {
-		return new Key(Elektra.INSTANCE.ksAtCursor(get(), cursor));
+	public Key at (final int cursor)
+	{
+		return new Key (Elektra.INSTANCE.ksAtCursor (get (), cursor));
 	}
 
 	/**
@@ -324,11 +348,13 @@ public class KeySet implements java.lang.Iterable<Key> {
 	 * @param options Custom search options; concatenation of flags
 	 * @return Key if search successful, null otherwise
 	 */
-	public Key lookup(final Key find, final int options) {
-		if (find == null) {
+	public Key lookup (final Key find, final int options)
+	{
+		if (find == null)
+		{
 			return null;
 		}
-		return new Key(Elektra.INSTANCE.ksLookup(ks, find.get(), options));
+		return new Key (Elektra.INSTANCE.ksLookup (ks, find.get (), options));
 	}
 
 	/**
@@ -337,11 +363,13 @@ public class KeySet implements java.lang.Iterable<Key> {
 	 * @param find Key used in search
 	 * @return Key if search successful, null otherwise
 	 */
-	public Key lookup(final Key find) {
-		if (find == null) {
+	public Key lookup (final Key find)
+	{
+		if (find == null)
+		{
 			return null;
 		}
-		return new Key(Elektra.INSTANCE.ksLookup(ks, find.get(), 0));
+		return new Key (Elektra.INSTANCE.ksLookup (ks, find.get (), 0));
 	}
 
 	/**
@@ -351,8 +379,9 @@ public class KeySet implements java.lang.Iterable<Key> {
 	 * @param options Custom search options; concatenation of flags
 	 * @return Key if search successful, null otherwise
 	 */
-	public Key lookup(final String find, final int options) {
-		return new Key(Elektra.INSTANCE.ksLookupByName(ks, find, options));
+	public Key lookup (final String find, final int options)
+	{
+		return new Key (Elektra.INSTANCE.ksLookupByName (ks, find, options));
 	}
 
 	/**
@@ -361,8 +390,9 @@ public class KeySet implements java.lang.Iterable<Key> {
 	 * @param find Key name used in search
 	 * @return Key if search successful, null otherwise
 	 */
-	public Key lookup(final String find) {
-		return new Key(Elektra.INSTANCE.ksLookupByName(ks, find, 0));
+	public Key lookup (final String find)
+	{
+		return new Key (Elektra.INSTANCE.ksLookupByName (ks, find, 0));
 	}
 
 	/**
@@ -370,7 +400,8 @@ public class KeySet implements java.lang.Iterable<Key> {
 	 *
 	 * @return Native pointer object used for this key set
 	 */
-	protected Pointer get() {
+	public Pointer get ()
+	{
 		return ks;
 	}
 }
