@@ -11,6 +11,8 @@
 #include <stdint.h>
 #include <stdlib.h>
 
+#include <kdbtypes.h>
+
 /**
  * Order Preserving Minimal Perfect Hash Map
  *
@@ -36,12 +38,6 @@
  * To save space the limit of elements is set to (2^32) - 1.
  */
 
-#if SIZEOF_SIZE_T == 8
-#define KDB_OPMPHM_MAX_N 4294967295 // = (2^32) - 1
-#else
-#define KDB_OPMPHM_MAX_N 795364313 // bound by opmphm->size max value
-#endif
-
 /**
  * The r-uniform r-partite hypergraph
  */
@@ -66,6 +62,27 @@ typedef struct
 	uint32_t removeIndex;      /*!< the index used for insertion in removeSequence */
 } OpmphmGraph;
 
+/**
+ * Opmphm Flags.
+ */
+typedef enum
+{
+	OPMPHM_FLAG_MMAP_STRUCT = 1 /*!<
+		 Opmphm struct lies inside a mmap region.
+		 This flag is set for Opmphm structs inside a mapped region.
+		 It prevents erroneous free() calls on these Opmphm structs. */
+	,
+	OPMPHM_FLAG_MMAP_HASHFUNCTIONSEEDS = 1 << 2 /*!<
+		Opmphm hashFunctionSeeds lies inside a mmap region.
+		This flag is set for Opmphm hashFunctionSeeds inside a mapped region.
+		It prevents erroneous free() calls on these hashFunctionSeeds. */
+	,
+	OPMPHM_FLAG_MMAP_GRAPH = 1 << 3 /*!<
+		Opmphm graph lies inside a mmap region.
+		This flag is set for Opmphm graphs inside a mapped region.
+		It prevents erroneous free() calls on these graphs. */
+} opmphmflag_t;
+
 /**
  * The opmphm
  */
@@ -76,6 +93,7 @@ typedef struct
 	size_t componentSize;	/*!< the number of vertices in one part of the r-uniform r-partite hypergraph */
 	uint32_t * graph;	    /*!< array containing the final OPMPHM */
 	size_t size;		     /*!< size of g in bytes */
+	opmphmflag_t flags;	  /*!< internal flags */
 } Opmphm;
 
 /**
