@@ -364,6 +364,8 @@ ssize_t keySetString (Key * key, const char * newStringValue)
 	else
 		ret = keySetRaw (key, newStringValue, elektraStrLen (newStringValue));
 
+	keySetMeta (key, "origvalue", 0);
+
 	return ret;
 }
 
@@ -515,7 +517,7 @@ ssize_t keySetRaw (Key * key, const void * newBinary, size_t dataSize)
 		{
 			if (!test_bit (key->flags, KEY_FLAG_MMAP_DATA)) elektraFree (key->data.v);
 			key->data.v = NULL;
-			clear_bit (key->flags, KEY_FLAG_MMAP_DATA);
+			clear_bit (key->flags, (keyflag_t) KEY_FLAG_MMAP_DATA);
 		}
 		key->dataSize = 0;
 		set_bit (key->flags, KEY_FLAG_SYNC);
@@ -530,7 +532,7 @@ ssize_t keySetRaw (Key * key, const void * newBinary, size_t dataSize)
 
 		if (test_bit (key->flags, KEY_FLAG_MMAP_DATA))
 		{
-			clear_bit (key->flags, KEY_FLAG_MMAP_DATA);
+			clear_bit (key->flags, (keyflag_t) KEY_FLAG_MMAP_DATA);
 			key->data.v = elektraMalloc (key->dataSize);
 			if (key->data.v == NULL) return -1;
 		}
