@@ -293,6 +293,15 @@ void Plugin::check (vector<string> & warnings)
 		ret = checkDups.insert (symbols["set"]);
 		if (!ret.second) throw SymbolDuplicate ("set");
 	}
+	if (plugin->kdbCommit)
+	{
+		if (symbols.find ("commit") == symbols.end ())
+			warnings.push_back ("no commit symbol exported");
+		else if (symbols["commit"] != reinterpret_cast<func_t> (plugin->kdbCommit))
+			throw SymbolMismatch ("commit");
+		ret = checkDups.insert (symbols["commit"]);
+		if (!ret.second) throw SymbolDuplicate ("commit");
+	}
 	if (plugin->kdbError)
 	{
 		if (symbols.find ("error") == symbols.end ())
@@ -318,6 +327,10 @@ void Plugin::check (vector<string> & warnings)
 	{
 		if (!plugin->kdbSet) throw SymbolMismatch ("set");
 	}
+	if (symbols.find ("commit") != symbols.end ())
+	{
+		if (!plugin->kdbCommit) throw SymbolMismatch ("commit");
+	}
 	if (symbols.find ("error") != symbols.end ())
 	{
 		if (!plugin->kdbError) throw SymbolMismatch ("error");
@@ -424,6 +437,16 @@ int Plugin::set (kdb::KeySet & ks, kdb::Key & parentKey)
 	return plugin->kdbSet (plugin, ks.getKeySet (), parentKey.getKey ());
 }
 
+int Plugin::commit (kdb::KeySet & ks, kdb::Key & parentKey)
+{
+	if (!plugin->kdbCommit)
+	{
+		throw MissingSymbol ("kdbCommit");
+	}
+
+	return plugin->kdbCommit (plugin, ks.getKeySet (), parentKey.getKey ());
+}
+
 int Plugin::error (kdb::KeySet & ks, kdb::Key & parentKey)
 {
 	if (!plugin->kdbError)
