@@ -13,6 +13,12 @@
 #include <kdb.h>
 #include <kdbtypes.h>
 
+#ifdef __cplusplus
+extern "C" {
+using Key = ckdb::Key;
+using KeySet = ckdb::KeySet;
+#endif
+
 #define ELEKTRA_CRYPTO_BOTAN_KEYSIZE (32)
 #define ELEKTRA_CRYPTO_BOTAN_BLOCKSIZE (16)
 #define ELEKTRA_CRYPTO_BOTAN_ALGORITHM "AES-256/CBC"
@@ -22,4 +28,8 @@ int elektraCryptoBotanInit (Key * errorKey);
 int elektraCryptoBotanEncrypt (KeySet * pluginConfig, Key * k, Key * errorKey, Key * masterKey);
 int elektraCryptoBotanDecrypt (KeySet * pluginConfig, Key * k, Key * errorKey, Key * masterKey);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif
