@@ -22,7 +22,7 @@
 
 
 //
-// use a ISO format string table to validate the key value
+// use an ISO format string table to validate the key value
 //
 
 static int individualIsoStringValidation (const char * date, const RepStruct * formats, ISOType opts)
@@ -411,7 +411,7 @@ static int validateKey (Key * key, Key * parentKey)
 		rc = formatStringValidation (date, formatString);
 		if (rc == -1)
 		{
-			ELEKTRA_SET_ERRORF (ELEKTRA_ERROR_D_T_FMT, parentKey, "%s doesn't match format string %s", date, formatString);
+			ELEKTRA_SET_VALIDATION_SYNTACTIC_ERRORF (parentKey, "Date '%s' doesn't match format string %s", date, formatString);
 			rc = 0;
 		}
 	}
@@ -421,15 +421,15 @@ static int validateKey (Key * key, Key * parentKey)
 		if (rc == -1)
 		{
 			if (formatString)
-				ELEKTRA_SET_ERRORF (ELEKTRA_ERROR_D_T_FMT, parentKey, "%s doesn't match iso specification %s", date,
-						    formatString);
+				ELEKTRA_SET_VALIDATION_SYNTACTIC_ERRORF (parentKey, "Date '%s' doesn't match iso specification %s", date,
+									 formatString);
 			else
-				ELEKTRA_SET_ERRORF (ELEKTRA_ERROR_D_T_FMT, parentKey, "%s is not a valid ISO8601 date", date);
+				ELEKTRA_SET_VALIDATION_SYNTACTIC_ERRORF (parentKey, "Date '%s' is not a valid ISO8601 date", date);
 			rc = 0;
 		}
 		else if (rc == 0)
 		{
-			ELEKTRA_SET_ERRORF (ELEKTRA_ERROR_D_T_FMT, parentKey, "syntax error in ISO8601 format string '%s'", formatString);
+			ELEKTRA_SET_VALIDATION_SYNTACTIC_ERRORF (parentKey, "Syntax error in ISO8601 format string '%s'", formatString);
 		}
 	}
 	else if (!strcasecmp (stdString, "RFC2822"))
@@ -437,7 +437,7 @@ static int validateKey (Key * key, Key * parentKey)
 		rc = rfc2822StringValidation (date);
 		if (rc == -1)
 		{
-			ELEKTRA_SET_ERRORF (ELEKTRA_ERROR_D_T_FMT, parentKey, "%s doesn't match rfc2822 specification", date);
+			ELEKTRA_SET_VALIDATION_SYNTACTIC_ERRORF (parentKey, "Date '%s' doesn't match rfc2822 specification", date);
 			rc = 0;
 		}
 	}
@@ -446,7 +446,7 @@ static int validateKey (Key * key, Key * parentKey)
 		rc = rfc822StringValidation (date);
 		if (rc == -1)
 		{
-			ELEKTRA_SET_ERRORF (ELEKTRA_ERROR_D_T_FMT, parentKey, "%s doesn't match format string %s", date, formatString);
+			ELEKTRA_SET_VALIDATION_SYNTACTIC_ERRORF (parentKey, "Date '%s' doesn't match format string %s", date, formatString);
 			rc = 0;
 		}
 	}
@@ -465,7 +465,7 @@ int elektraDateGet (Plugin * handle ELEKTRA_UNUSED, KeySet * returned ELEKTRA_UN
 			       keyNew ("system/elektra/modules/date/exports/get", KEY_FUNC, elektraDateGet, KEY_END),
 			       keyNew ("system/elektra/modules/date/exports/set", KEY_FUNC, elektraDateSet, KEY_END),
 			       keyNew ("system/elektra/modules/date/exports/validateKey", KEY_FUNC, validateKey, KEY_END),
-#include ELEKTRA_README (date)
+#include ELEKTRA_README
 			       keyNew ("system/elektra/modules/date/infos/version", KEY_VALUE, PLUGINVERSION, KEY_END), KS_END);
 		ksAppend (returned, contract);
 		ksDel (contract);
@@ -511,7 +511,7 @@ int elektraDateSet (Plugin * handle ELEKTRA_UNUSED, KeySet * returned ELEKTRA_UN
 	return rc; // success
 }
 
-Plugin * ELEKTRA_PLUGIN_EXPORT (date)
+Plugin * ELEKTRA_PLUGIN_EXPORT
 {
 	// clang-format off
 	return elektraPluginExport ("date",
