@@ -9,5 +9,10 @@ CppKeySet { 10,
 	    keyNew (PREFIX "key/array/#2/nested", KEY_END),
 	    keyNew (PREFIX "key/array/#2/nested/#0", KEY_END),
 	    keyNew (PREFIX "key/array/#2/nested/#1", KEY_END),
+	    keyNew (PREFIX "key/array/#3/not/an/array", KEY_END),
+	    keyNew (PREFIX "key/array/#3/not/an/array/#0", KEY_END),
+	    keyNew (PREFIX "key/array/#3/not/an/array/key", KEY_END),
+	    keyNew (PREFIX "key/array/#4/array/without/parent/#0", KEY_END),
+	    keyNew (PREFIX "key/array/#4/array/without/parent/#1", KEY_END),
 	    keyNew (PREFIX "key/empty/array", KEY_META, "array", "", KEY_END),
 	    KS_END }
