@@ -153,8 +153,8 @@ static gpgme_key_t * extractRecipientFromPluginConfig (KeySet * config, Key * er
 		err = gpgme_get_key (ctx, keyString (gpgRecipientRoot), &key, 0);
 		if (err)
 		{
-			// TODO: Correct??
-			ELEKTRA_SET_INTERNAL_ERRORF (errorKey, "Failed to receive the GPG key. Reason: %s", gpgme_strerror (err));
+			ELEKTRA_SET_VALIDATION_SEMANTIC_ERRORF (errorKey, "Failed to read the specified GPG key. Reason: %s",
+								gpgme_strerror (err));
 			elektraGpgmeKeylistFree (&list);
 			return NULL;
 		}
@@ -163,7 +163,7 @@ static gpgme_key_t * extractRecipientFromPluginConfig (KeySet * config, Key * er
 		{
 			if (!elektraGpgmeKeylistAdd (&list, key))
 			{
-				ELEKTRA_SET_OUT_OF_MEMORY_ERROR (errorKey, "Memory allocation failed");
+				ELEKTRA_SET_OUT_OF_MEMORY_ERROR (errorKey);
 				elektraGpgmeKeylistFree (&list);
 				return NULL;
 			}
@@ -183,9 +183,8 @@ static gpgme_key_t * extractRecipientFromPluginConfig (KeySet * config, Key * er
 				err = gpgme_get_key (ctx, keyString (k), &key, 0);
 				if (err)
 				{
-					// TODO: Correct??
-					ELEKTRA_SET_INTERNAL_ERRORF (errorKey, "Failed to receive the GPG key. Reason: %s",
-								     gpgme_strerror (err));
+					ELEKTRA_SET_VALIDATION_SEMANTIC_ERRORF (
+						errorKey, "Failed to read the specified GPG key. Reason: %s", gpgme_strerror (err));
 					elektraGpgmeKeylistFree (&list);
 					return NULL;
 				}
@@ -194,7 +193,7 @@ static gpgme_key_t * extractRecipientFromPluginConfig (KeySet * config, Key * er
 				{
 					if (!elektraGpgmeKeylistAdd (&list, key))
 					{
-						ELEKTRA_SET_OUT_OF_MEMORY_ERROR (errorKey, "Memory allocation failed");
+						ELEKTRA_SET_OUT_OF_MEMORY_ERROR (errorKey);
 						elektraGpgmeKeylistFree (&list);
 						return NULL;
 					}
@@ -212,7 +211,7 @@ static gpgme_key_t * extractRecipientFromPluginConfig (KeySet * config, Key * er
 		gpgme_key_t * keyArray = elektraMalloc ((list.size + 1) * sizeof (gpgme_key_t));
 		if (!keyArray)
 		{
-			ELEKTRA_SET_OUT_OF_MEMORY_ERROR (errorKey, "Memory allocation failed");
+			ELEKTRA_SET_OUT_OF_MEMORY_ERROR (errorKey);
 			elektraGpgmeKeylistFree (&list);
 			return NULL;
 		}
@@ -251,7 +250,7 @@ static int transferGpgmeDataToElektraKey (gpgme_data_t src, Key * dst, Key * err
 	buffer = (char *) elektraMalloc (ciphertextLen);
 	if (!buffer)
 	{
-		ELEKTRA_SET_OUT_OF_MEMORY_ERROR (errorKey, "Memory allocation failed");
+		ELEKTRA_SET_OUT_OF_MEMORY_ERROR (errorKey);
 		returnValue = -1; // failure
 		goto cleanup;
 	}
@@ -260,7 +259,7 @@ static int transferGpgmeDataToElektraKey (gpgme_data_t src, Key * dst, Key * err
 	readCount = gpgme_data_read (src, buffer, ciphertextLen);
 	if (readCount != ciphertextLen)
 	{
-		ELEKTRA_SET_INTERNAL_ERRORF (errorKey, "An error during occurred during the data transfer. Reason: %s", strerror (errno));
+		ELEKTRA_SET_INTERNAL_ERRORF (errorKey, "An error occurred during the en/decryption process. Reason: %s", strerror (errno));
 		returnValue = -1; // failure
 		goto cleanup;
 	}
@@ -351,7 +350,7 @@ static int gpgEncrypt (Plugin * handle, KeySet * data, Key * errorKey)
 	err = gpgme_new (&ctx);
 	if (err)
 	{
-		ELEKTRA_SET_INSTALLATION_ERRORF (errorKey, "Failed to create the gpgme context. Reason: %s", gpgme_strerror (err));
+		ELEKTRA_SET_INSTALLATION_ERRORF (errorKey, "Failed to initialize gpgme. Reason: %s", gpgme_strerror (err));
 		return -1; // at this point nothing has been initialized
 	}
 
@@ -439,7 +438,7 @@ static int gpgEncrypt (Plugin * handle, KeySet * data, Key * errorKey)
 			}
 			else
 			{
-				ELEKTRA_SET_OUT_OF_MEMORY_ERROR (errorKey, "Memory allocation failed");
+				ELEKTRA_SET_OUT_OF_MEMORY_ERROR (errorKey);
 			}
 			gpgme_data_release (ciphertext);
 			gpgme_data_release (input);
@@ -486,7 +485,7 @@ static int gpgDecrypt (ELEKTRA_UNUSED Plugin * handle, KeySet * data, Key * erro
 	err = gpgme_new (&ctx);
 	if (err)
 	{
-		ELEKTRA_SET_INSTALLATION_ERRORF (errorKey, "Failed to the gpgme context. Reason: %s", gpgme_strerror (err));
+		ELEKTRA_SET_INSTALLATION_ERRORF (errorKey, "Failed to initialize gpgme. Reason: %s", gpgme_strerror (err));
 		return -1; // at this point nothing has been initialized
 	}
 
@@ -602,7 +601,7 @@ int elektraGpgmeCheckconf (Key * errorKey, KeySet * conf)
 	err = gpgme_new (&ctx);
 	if (err)
 	{
-		ELEKTRA_SET_INSTALLATION_ERRORF (errorKey, "Failed to create the gpgme context. Reason: %s", gpgme_strerror (err));
+		ELEKTRA_SET_INSTALLATION_ERRORF (errorKey, "Failed to initialize gpgme. Reason: %s", gpgme_strerror (err));
 		return -1; // at this point nothing has been initialized
 	}
 
