@@ -75,8 +75,9 @@ int elektraPortInfo (Key * toCheck, Key * parentKey)
 		service = getservbyname (keyString (toCheck), NULL); // NULL means we accept both tcp and udp
 		if (service == NULL)
 		{
-			ELEKTRA_SET_VALIDATION_SEMANTIC_ERRORF (parentKey, "Could not find service with name %s on key %s. Reason: %s",
-								keyString (toCheck), keyName (toCheck), strerror (errno));
+			// `getservbyname` does not set any errno
+			ELEKTRA_SET_VALIDATION_SEMANTIC_ERRORF (parentKey, "Could not find service with name %s on key %s",
+								keyString (toCheck), keyName (toCheck));
 			return -1;
 		}
 		portNumberNetworkByteOrder = service->s_port;
