@@ -12,12 +12,16 @@
 
 #include <kdbplugin.h>
 
+using ckdb::Key;
+using ckdb::KeySet;
+using ckdb::Plugin;
+
 extern "C" {
 
 int elektraYamlcppGet (ckdb::Plugin * handle, ckdb::KeySet * ks, ckdb::Key * parentKey);
 int elektraYamlcppSet (ckdb::Plugin * handle, ckdb::KeySet * ks, ckdb::Key * parentKey);
 
-ckdb::Plugin * ELEKTRA_PLUGIN_EXPORT (yamlcpp);
+ckdb::Plugin * ELEKTRA_PLUGIN_EXPORT;
 
 } // end extern "C"
 
