@@ -3,12 +3,12 @@
  *
  * @brief
  *
- * @copyright BSD License (see doc/LICENSE.md or http://www.libelektra.org)
+ * @copyright BSD License (see LICENSE.md or https://www.libelektra.org)
  */
 
 #include <tests_internal.h>
 
-static void test_ksNew ()
+static void test_ksNew (void)
 {
 	KeySet * ks = 0;
 	KeySet * keys = ksNew (15, KS_END);
@@ -75,7 +75,7 @@ static void test_ksNew ()
 	succeed_if (ksDel (ks2) == 0, "could not delete keyset");
 }
 
-static void test_ksDuplicate ()
+static void test_ksDuplicate (void)
 {
 	printf ("Test bug duplicate\n");
 	KeySet * ks = ksNew (0, KS_END);
@@ -89,7 +89,7 @@ static void test_ksDuplicate ()
 	ksDel (ks);
 }
 
-static void test_ksHole ()
+static void test_ksHole (void)
 {
 	printf ("Test holes in keysets\n");
 	KeySet * ks = ksNew (0, KS_END);
@@ -116,13 +116,12 @@ int fac (int i)
 static void per (int k, Key ** pool, Key ** result)
 {
 	int i;
-	int selected;
 	int cursize = size - 1;
 
 	for (i = 0; i < size - 1; ++i)
 	{
 		// printf ("%d -- ", k);
-		selected = k % (cursize);
+		int selected = k % (cursize);
 		k /= cursize + 1;
 		cursize--;
 
@@ -137,7 +136,7 @@ static void per (int k, Key ** pool, Key ** result)
 	result[size - 1] = 0;
 }
 
-static void test_append ()
+static void test_append (void)
 {
 	printf ("Test if keyset is sorted after appending\n");
 
@@ -315,7 +314,7 @@ static void test_append ()
 	keyDel (s3);
 }
 
-static void test_equal ()
+static void test_equal (void)
 {
 	Key * k1 = keyNew (0);
 	Key * k2 = keyNew (0);
@@ -343,7 +342,7 @@ static void test_equal ()
 	keyDel (k2);
 }
 
-static void test_cmp ()
+static void test_cmp (void)
 {
 	printf ("Compare two keys\n");
 
@@ -381,7 +380,7 @@ static void test_cmp ()
 	keyDel (k2);
 }
 
-static void test_appendowner ()
+static void test_appendowner (void)
 {
 	Key *key, *s1, *s2, *s3;
 	KeySet * ks;
@@ -423,19 +422,7 @@ static void test_appendowner ()
 	ksDel (ks);
 }
 
-static void test_ksLookupCase ()
-{
-	printf ("Test bug lookup with case\n");
-	KeySet * ks = ksNew (32, keyNew ("system/ay/key", KEY_VALUE, "aykey", KEY_END),
-			     keyNew ("system/mY/kex", KEY_VALUE, "mykex", KEY_END), keyNew ("system/xy/key", KEY_VALUE, "xykey", KEY_END),
-			     keyNew ("system/My/key", KEY_VALUE, "Mykey", KEY_END), KS_END);
-	// Does not work without KDB_O_NOALL
-	Key * found = ksLookupByName (ks, "system/my/key", KDB_O_NOCASE | KDB_O_NOALL);
-	succeed_if (found != 0, "could not find key (binary search fails when ignoring case)");
-	ksDel (ks);
-}
-
-static void test_ksLookupOwner ()
+static void test_ksLookupOwner (void)
 {
 	printf ("Test bug lookup with owner\n");
 	Key * found = 0;
@@ -443,21 +430,6 @@ static void test_ksLookupOwner ()
 			     keyNew ("user:frotz/my/key", KEY_VALUE, "frotz", KEY_END),
 			     keyNew ("user/my/key", KEY_VALUE, "current", KEY_END), KS_END);
 
-	found = ksLookupByName (ks, "user/my/key", KDB_O_WITHOWNER);
-	succeed_if (found != 0, "could not find key");
-	succeed_if (!strcmp (keyValue (found), "current"), "got wrong key");
-
-	found = ksLookupByName (ks, "user:fritz/my/key", KDB_O_WITHOWNER);
-	succeed_if (found != 0, "could not find key");
-	succeed_if (!strcmp (keyValue (found), "fritz"), "got wrong key");
-
-	found = ksLookupByName (ks, "user:frotz/my/key", KDB_O_WITHOWNER);
-	succeed_if (found != 0, "could not find key");
-	succeed_if (!strcmp (keyValue (found), "frotz"), "got wrong key");
-
-	found = ksLookupByName (ks, "user:fretz/my/key", KDB_O_WITHOWNER);
-	succeed_if (found == 0, "found non existing key");
-
 	found = ksLookupByName (ks, "user/my/key", 0);
 	succeed_if (found != 0, "could not find key");
 	succeed_if (!strcmp (keyValue (found), "fritz"), "binary search seems to be non-deterministic");
@@ -492,7 +464,6 @@ int main (int argc, char ** argv)
 	test_equal ();
 	test_cmp ();
 	test_appendowner ();
-	test_ksLookupCase ();
 	test_ksLookupOwner ();
 
 	printf ("\n%s RESULTS: %d test(s) done. %d error(s).\n", argv[0], nbTest, nbError);
