@@ -20,6 +20,11 @@
 
 #include <gtest/gtest.h>
 #include <kdb.hpp>
+#include <kdbconfig.h>
+
+#ifdef ENABLE_ASAN
+#include <sanitizer/lsan_interface.h>
+#endif
 
 std::vector<std::string> getAllPlugins ()
 {
@@ -28,17 +33,40 @@ std::vector<std::string> getAllPlugins ()
 	ModulesPluginDatabase mpd;
 	std::vector<std::string> plugins = mpd.listAllPlugins ();
 
-	// remove known problems
-	plugins.erase (std::remove (plugins.begin (), plugins.end (), "haskell"), plugins.end ());
-	plugins.erase (std::remove (plugins.begin (), plugins.end (), "xerces"), plugins.end ());
-	plugins.erase (std::remove (plugins.begin (), plugins.end (), "ruby"), plugins.end ());
+	// The JNI and Ruby plugins cause segmentation faults
 	plugins.erase (std::remove (plugins.begin (), plugins.end (), "jni"), plugins.end ());
-	plugins.erase (std::remove (plugins.begin (), plugins.end (), "crypto_gcrypt"), plugins.end ());
-	plugins.erase (std::remove (plugins.begin (), plugins.end (), "crypto_openssl"), plugins.end ());
-	plugins.erase (std::remove (plugins.begin (), plugins.end (), "crypto_botan"), plugins.end ());
+	plugins.erase (std::remove (plugins.begin (), plugins.end (), "ruby"), plugins.end ());
 
-	// Valgrind reports memory leaks for the `semlock` plugin on Debian Unstable: http://issues.libelektra.org/2113
-	plugins.erase (std::remove (plugins.begin (), plugins.end (), "semlock"), plugins.end ());
+#ifdef ENABLE_ASAN
+	// ASAN reports memory leaks for the Augeas plugin on macOS: https://travis-ci.org/sanssecours/elektra/jobs/418524229
+	plugins.erase (std::remove (plugins.begin (), plugins.end (), "augeas"), plugins.end ());
+
+	std::vector<std::string> pluginsWithMemoryLeaks;
+
+	for (auto plugin : plugins)
+	{
+		try
+		{
+#ifndef ASAN_NO_LEAK_SANITIZER_SUPPORT
+			__lsan_disable ();
+#endif
+			auto status = mpd.lookupInfo (PluginSpec (plugin), "status");
+#ifndef ASAN_NO_LEAK_SANITIZER_SUPPORT
+			__lsan_enable ();
+#endif
+			if (status.find ("memleak")) pluginsWithMemoryLeaks.push_back (plugin);
+		}
+		catch (std::exception const & error)
+		{
+			std::cerr << "Unable to determine status of plugin “" << plugin << "”: " << error.what () << std::endl;
+		}
+	}
+
+	for (auto plugin : pluginsWithMemoryLeaks)
+	{
+		plugins.erase (std::remove (plugins.begin (), plugins.end (), plugin), plugins.end ());
+	}
+#endif
 
 	return plugins;
 }
@@ -53,7 +81,7 @@ TEST_P (AllPlugins, backend)
 	using namespace kdb;
 	using namespace kdb::tools;
 	std::string p = GetParam ();
-	// std::cout << p << std::endl;
+	std::cout << p << std::endl;
 
 	try
 	{
@@ -71,7 +99,7 @@ TEST_P (AllPlugins, modules)
 	using namespace kdb;
 	using namespace kdb::tools;
 	std::string p = GetParam ();
-	// std::cout << p << std::endl;
+	std::cout << p << std::endl;
 
 	try
 	{
