@@ -15,12 +15,11 @@ test -f "@PROJECT_BINARY_DIR@/compile_commands.json" || {
 }
 
 cd "@CMAKE_SOURCE_DIR@" || exit
-oclint -p "@PROJECT_BINARY_DIR@" -enable-global-analysis -enable-clang-static-analyzer \
+oclint -p "@PROJECT_BINARY_DIR@" -no-analytics -enable-global-analysis -enable-clang-static-analyzer \
 	"src/libs/ease/array.c" \
 	"src/libs/ease/keyname.c" \
 	"src/libs/utility/text.c" \
 	"src/plugins/base64/"*.c \
-	"src/plugins/camel/camel.c" \
 	"src/plugins/ccode/"*.cpp \
 	"src/plugins/cpptemplate/"*.cpp \
 	"src/plugins/directoryvalue/"*.cpp \
@@ -28,8 +27,7 @@ oclint -p "@PROJECT_BINARY_DIR@" -enable-global-analysis -enable-clang-static-an
 	"src/plugins/yambi/"*.cpp \
 	"src/plugins/yamlcpp/"*.{c,cpp} \
 	"src/plugins/yamlsmith/"*.{c,cpp} \
-	"src/plugins/yanlr/"*.{c,cpp} \
-	"src/plugins/yawn/"*.cpp
+	"src/plugins/yanlr/"*.cpp
 exit_if_fail "OCLint found problematic code"
 
 end_script
